; --------------------------------------------------------------------------
; Teste do LCD HD44780 na configuracao de 4 BITS                  26/07/2014
;
; STATUS: FUNCIONA 
;
; HARDWARE
; Fosc .................. interno 4MHZ
; RA0 ................... ao RS do LCD
; RA1 ................... ao EN do LCD
; RB4 ................... ao D4 do LCD
; RB5 ................... ao D5 do LCD
; RB6 ................... ao D6 do LCD
; RB7 ................... ao D7 do LCD
; 
; ATENCAO: 
; OS PINOS D0, D1, D2 e D3 do LCD devem ficar desconectados.
;
;--------------------------------------------------------------------
; 
	list      p=16f628a 
    #include <p16F628A.inc>
	errorlevel  -302 

	__CONFIG   _CP_OFF &  _LVP_OFF & _BOREN_OFF & _MCLRE_OFF & _WDT_OFF & _PWRTE_ON & _INTOSC_OSC_NOCLKOUT
;
;--------------------------------------------------------------------
; 
                #include      "FAMILIAS.mac"     ; Macro para detectar o modelo de PIC
                #include      "LCD_LINES.mac"    ; Macro para informar o modelo de LCD
                #include      "SET_CURSOR.mac"   ; Macro para posicionamento de cursor do LCD
                #include      "SR_4MVC.mac"      ; Macro para enviar uma string ao LCD
;
;--------------------------------------------------------------------
; 
                FAMILIAS      ; detecta o modelo de PIC
;
;--------------------------------------------------------------------
; 
                UDATA       0x20                 ; RAM
delay_temp      RES   1                          ; para uso da rotina de delay
CLOCK           equ   4000000                    ; Fosc
;
; Registradores e simbolos para a subrotina de controle do LCD
;
#define         _PARALLEL_LCD                    ; LCD com conexoes normais
LCD_R0          RES   1                          ; registrador de trabalho 0
LCD_R1          RES   1                          ; registrador de trabalho 1
LCD_R2          RES   1                          ; registrador de trabalho 2
LCD_COMMAND     RES   1                          ; buffer de comando
LCD_TRIS_port   equ   TRISB                      ; registrador de controle de LCD_port
LCD_port        equ   PORTB                      ; nome da porta de dados do LDC (PORTA, PORTB,GPIO, etc)
;
LCD_TRIS_cntl   equ   TRISA                      ; registrador de controle de LCD_cntl
LCD_cntl        equ   PORTA                      ; nome da porta de controle (PORTA, PORTB,GPIO, etc)
LCD_EN          equ   1                          ; 
LCD_RS          equ   0                          ; 
;
                #include      "GPR.inc"          ; registradores de trabalho (R0 a R15)
; ---------------------------------------------------------------
RESET_VECTOR CODE    0x0000
             goto    inicio
;
INT_VEC1     CODE    0x0004
             retfie                              ; nao ha interrupcoes
; ---------------------------------------------------------------
MAIN        CODE  
            LCD_LINES  0216                      ; modelo de LCD
;
msg1        SR_4MVC m001
m001        addwf  PCL,f
            DT     " Visite-nos em",0            ; mensagem
;
msg2        SR_4MVC m002
m002        addwf  PCL,f
            DT     " hpspin.com.br",0            ; mensagem

; ---------------------------------------------------------------
inicio    movlw    0x07                 ;
          movwf    CMCON                ; desliga todos os comparadores 
;
          clrf     PORTA                ; limpa PORTA
          clrf     PORTB                ; limpa PORTB
;
          bsf      STATUS,RP0          ; banco 1
          movlw    0xFC                ; mascara de I/O do PORTA
          movwf    TRISA               ; I/O do PORTA
          movlw    0x0F                ; mascara de I/O do PORTB
          movwf    TRISB               ; I/O do PORTB
          bcf      STATUS,RP0          ; banco 0
;
          call   SR_4BITS              ; configura o LCD
          call   SR_LCDRESET           ; limpa o LCD
;
denovo    nop
          SET_CURSOR .1,.1,"i"         ; posiciona o cursor
          call     msg1                ; envia " Visite-nos em"
          call     long_wait           ; tempo para visualizacao
          call     long_wait           ; tempo para visualizacao

          SET_CURSOR  .2,.1,"i"        ; posiciona o cursor
          call     msg2                ; envia " hpspin.com.br"
          call     long_wait           ; tempo para visualizacao
          call     long_wait           ; tempo para visualizacao

          call     SR_LCDCLEAR         ; limpa o LCD
          call     long_wait           ; tempo para visualizacao 
          call     long_wait           ; tempo para visualizacao
          goto     denovo              ; fica em loop
;
; Rotina de tempo
; Esta rotina causa um retardo de 1 segundo (4 x 250ms)
;
long_wait movlw    .250
          call     delay_ms   
          movlw    .250
          call     delay_ms
          movlw    .250
          call     delay_ms   
          movlw    .250
          call     delay_ms   
          return
;
;         SUBROTINAS USADAS NESTE PROGRAMA
;
          #include  "delay_ms.inc"     ; retardo de tempo em milisegundos
          #include  "delay_us.inc"     ; retardo de tempo em microsegundos
          #include  "lcdhd44780.asm"   ; funcoes de controle do LCD
;
          END
